@@ -4,6 +4,8 @@ from google.cloud import bigquery
 from google.api_core import exceptions
 from kafka.errors import KafkaError
 
+logger = logging.getLogger(__name__)
+
 
 def get_bq_table(bq_client: bigquery.Client, table_name: str) -> bigquery.table.Table:
     dataset_ref = bq_client.dataset(table_name.split(".")[0])
@@ -21,12 +23,10 @@ def write_bq(
         response = bq_client.insert_rows_json(bq_table, [message])
 
         if len(response) == 0:
-            logging.info("New rows have been added.")
+            logger.info("New rows have been added.")
         else:
-            logging.error("Encountered errors while inserting rows: {}".format(response))
-    except exceptions.ClientError:
-        logging.error("Kafka message is invalid")
-        raise KafkaError()
-
-
-
+            logger.error("Encountered errors while inserting rows: {}".format(response))
+    except exceptions.ClientError as error:
+        logger.error("BigQuery client error!")
+        logger.info(f"{error}")
+        raise KafkaError()
\ No newline at end of file
