@@ -38,8 +38,9 @@ class ConsumerApp:
         self._google_creds = google_creds
         self._app = FastAPI()
         self._is_alive = True
-        self._is_ready = True
+        self._is_ready = False
         self.add_endpoints()
+        self._logger = logging.getLogger(__name__)
         threading.Thread(target=self.read_topic, daemon=True).start()
 
     @property
@@ -48,12 +49,12 @@ class ConsumerApp:
 
     def read_topic(self):
         consumer = self.create_consumer()
-        logging.info("Created consumer")
+        self._logger.info("Kafka initialized")
         bq_client = self.create_bq_client()
-        logging.info("Created bq client")
         bq_table = bigquery_writer.get_bq_table(bq_client=bq_client,
                                                 table_name=self._bq_table)
-        logging.info("Fetched bq table")
+        self._logger.info("BigQuery connection established")
+        self._is_ready = True
 
         try:
             for mesg in consumer:
@@ -62,13 +63,14 @@ class ConsumerApp:
                                          bq_client=bq_client,
                                          bq_table=bq_table)
                 consumer.commit()
-                logging.info(
+                self._logger.info(
                     f"Wrote message with timestamp {kafka.convert_timestamp_to_datetime(mesg.timestamp)}"
                     f"to bigquery table {bq_table.dataset_id}.{bq_table.table_id}"
                 )
         except KafkaError:
             self._is_alive = False
 
+        self._logger.info("Kafka consumer stopped. Restarting app.")
         self._is_alive = False
         raise KafkaError()
 
@@ -90,7 +92,8 @@ class ConsumerApp:
                 content={"Status": f"NotReady"},
             )
 
-    def metrics(self):
+    @staticmethod
+    def metrics():
         return JSONResponse(status_code=status.HTTP_200_OK, content={"Status": f"Not implemented"})
 
     def add_endpoints(self):
@@ -121,6 +124,7 @@ class ConsumerApp:
                                      enable_auto_commit=False,
                                      api_version_auto_timeout_ms=10000)
         except NoBrokersAvailable:
+            self._logger.error("Kafka initialization error. Restarting app.")
             self._is_alive = False
         else:
             return consumer
